Jubatus Python Client
=====================

Template of Jubatus client in Python.
See `pypi <http://pypi.python.org/pypi/jubatus>`_ for the latest release.

All codes are generated by ``jenerator`` .

Install
=======

::

  $ pip install jubatus


License
=======

MIT License

